/*
 * Copyright 2010-2014 Ning, Inc.
 * Copyright 2014-2020 Groupon, Inc
 * Copyright 2020-2021 Equinix, Inc
 * Copyright 2014-2021 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */


package org.killbill.billing.client.model.gen;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;
import org.joda.time.LocalDate;
import org.killbill.billing.catalog.api.Currency;
import org.killbill.billing.client.model.gen.AuditLog;
import org.killbill.billing.client.model.gen.InvoiceItem;
import org.killbill.billing.invoice.api.InvoiceStatus;

/**
 *           DO NOT EDIT !!!
 *
 * This code has been generated by the Kill Bill swagger generator.
 *  @See https://github.com/killbill/killbill-swagger-coden
 */
import org.killbill.billing.client.model.KillBillObject;

public class Invoice extends KillBillObject {

    private BigDecimal amount = null;

    private Currency currency = null;

    private InvoiceStatus status = null;

    private BigDecimal creditAdj = null;

    private BigDecimal refundAdj = null;

    private UUID invoiceId = null;

    private LocalDate invoiceDate = null;

    private LocalDate targetDate = null;

    private String invoiceNumber = null;

    private BigDecimal balance = null;

    private UUID accountId = null;

    private String bundleKeys = null;

    private List<InvoiceItem> credits = null;

    private List<InvoiceItem> items = null;

    private List<String> trackingIds = null;

    private Boolean isParentInvoice = null;

    private UUID parentInvoiceId = null;

    private UUID parentAccountId = null;



    public Invoice() {
    }

    public Invoice(final BigDecimal amount,
                     final Currency currency,
                     final InvoiceStatus status,
                     final BigDecimal creditAdj,
                     final BigDecimal refundAdj,
                     final UUID invoiceId,
                     final LocalDate invoiceDate,
                     final LocalDate targetDate,
                     final String invoiceNumber,
                     final BigDecimal balance,
                     final UUID accountId,
                     final String bundleKeys,
                     final List<InvoiceItem> credits,
                     final List<InvoiceItem> items,
                     final List<String> trackingIds,
                     final Boolean isParentInvoice,
                     final UUID parentInvoiceId,
                     final UUID parentAccountId,
                     final List<AuditLog> auditLogs) {
        super(auditLogs);
        this.amount = amount;
        this.currency = currency;
        this.status = status;
        this.creditAdj = creditAdj;
        this.refundAdj = refundAdj;
        this.invoiceId = invoiceId;
        this.invoiceDate = invoiceDate;
        this.targetDate = targetDate;
        this.invoiceNumber = invoiceNumber;
        this.balance = balance;
        this.accountId = accountId;
        this.bundleKeys = bundleKeys;
        this.credits = credits;
        this.items = items;
        this.trackingIds = trackingIds;
        this.isParentInvoice = isParentInvoice;
        this.parentInvoiceId = parentInvoiceId;
        this.parentAccountId = parentAccountId;

    }


    public Invoice setAmount(final BigDecimal amount) {
        this.amount = amount;
        return this;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public Invoice setCurrency(final Currency currency) {
        this.currency = currency;
        return this;
    }

    public Currency getCurrency() {
        return currency;
    }

    public Invoice setStatus(final InvoiceStatus status) {
        this.status = status;
        return this;
    }

    public InvoiceStatus getStatus() {
        return status;
    }

    public Invoice setCreditAdj(final BigDecimal creditAdj) {
        this.creditAdj = creditAdj;
        return this;
    }

    public BigDecimal getCreditAdj() {
        return creditAdj;
    }

    public Invoice setRefundAdj(final BigDecimal refundAdj) {
        this.refundAdj = refundAdj;
        return this;
    }

    public BigDecimal getRefundAdj() {
        return refundAdj;
    }

    public Invoice setInvoiceId(final UUID invoiceId) {
        this.invoiceId = invoiceId;
        return this;
    }

    public UUID getInvoiceId() {
        return invoiceId;
    }

    public Invoice setInvoiceDate(final LocalDate invoiceDate) {
        this.invoiceDate = invoiceDate;
        return this;
    }

    public LocalDate getInvoiceDate() {
        return invoiceDate;
    }

    public Invoice setTargetDate(final LocalDate targetDate) {
        this.targetDate = targetDate;
        return this;
    }

    public LocalDate getTargetDate() {
        return targetDate;
    }

    public Invoice setInvoiceNumber(final String invoiceNumber) {
        this.invoiceNumber = invoiceNumber;
        return this;
    }

    public String getInvoiceNumber() {
        return invoiceNumber;
    }

    public Invoice setBalance(final BigDecimal balance) {
        this.balance = balance;
        return this;
    }

    public BigDecimal getBalance() {
        return balance;
    }

    public Invoice setAccountId(final UUID accountId) {
        this.accountId = accountId;
        return this;
    }

    public UUID getAccountId() {
        return accountId;
    }

    public Invoice setBundleKeys(final String bundleKeys) {
        this.bundleKeys = bundleKeys;
        return this;
    }

    public String getBundleKeys() {
        return bundleKeys;
    }

    public Invoice setCredits(final List<InvoiceItem> credits) {
        this.credits = credits;
        return this;
    }

    public Invoice addCreditsItem(final InvoiceItem creditsItem) {
        if (this.credits == null) {
            this.credits = new ArrayList<InvoiceItem>();
        }
        this.credits.add(creditsItem);
        return this;
    }

    public List<InvoiceItem> getCredits() {
        return credits;
    }

    public Invoice setItems(final List<InvoiceItem> items) {
        this.items = items;
        return this;
    }

    public Invoice addItemsItem(final InvoiceItem itemsItem) {
        if (this.items == null) {
            this.items = new ArrayList<InvoiceItem>();
        }
        this.items.add(itemsItem);
        return this;
    }

    public List<InvoiceItem> getItems() {
        return items;
    }

    public Invoice setTrackingIds(final List<String> trackingIds) {
        this.trackingIds = trackingIds;
        return this;
    }

    public Invoice addTrackingIdsItem(final String trackingIdsItem) {
        if (this.trackingIds == null) {
            this.trackingIds = new ArrayList<String>();
        }
        this.trackingIds.add(trackingIdsItem);
        return this;
    }

    public List<String> getTrackingIds() {
        return trackingIds;
    }

    public Invoice setIsParentInvoice(final Boolean isParentInvoice) {
        this.isParentInvoice = isParentInvoice;
        return this;
    }

    @JsonProperty(value="isParentInvoice")
    public Boolean isParentInvoice() {
        return isParentInvoice;
    }

    public Invoice setParentInvoiceId(final UUID parentInvoiceId) {
        this.parentInvoiceId = parentInvoiceId;
        return this;
    }

    public UUID getParentInvoiceId() {
        return parentInvoiceId;
    }

    public Invoice setParentAccountId(final UUID parentAccountId) {
        this.parentAccountId = parentAccountId;
        return this;
    }

    public UUID getParentAccountId() {
        return parentAccountId;
    }

    @Override
    public boolean equals(java.lang.Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Invoice invoice = (Invoice) o;
        return Objects.equals(this.amount, invoice.amount) &&
            Objects.equals(this.currency, invoice.currency) &&
            Objects.equals(this.status, invoice.status) &&
            Objects.equals(this.creditAdj, invoice.creditAdj) &&
            Objects.equals(this.refundAdj, invoice.refundAdj) &&
            Objects.equals(this.invoiceId, invoice.invoiceId) &&
            Objects.equals(this.invoiceDate, invoice.invoiceDate) &&
            Objects.equals(this.targetDate, invoice.targetDate) &&
            Objects.equals(this.invoiceNumber, invoice.invoiceNumber) &&
            Objects.equals(this.balance, invoice.balance) &&
            Objects.equals(this.accountId, invoice.accountId) &&
            Objects.equals(this.bundleKeys, invoice.bundleKeys) &&
            Objects.equals(this.credits, invoice.credits) &&
            Objects.equals(this.items, invoice.items) &&
            Objects.equals(this.trackingIds, invoice.trackingIds) &&
            Objects.equals(this.isParentInvoice, invoice.isParentInvoice) &&
            Objects.equals(this.parentInvoiceId, invoice.parentInvoiceId) &&
            Objects.equals(this.parentAccountId, invoice.parentAccountId) &&
            true /* ignoring this.auditLogs for identity operations */;
    }

    @Override
    public int hashCode() {
        return Objects.hash(amount,
            currency,
            status,
            creditAdj,
            refundAdj,
            invoiceId,
            invoiceDate,
            targetDate,
            invoiceNumber,
            balance,
            accountId,
            bundleKeys,
            credits,
            items,
            trackingIds,
            isParentInvoice,
            parentInvoiceId,
            parentAccountId,
            0 /* ignoring auditLogs for identity operations */ );
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Invoice {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    amount: ").append(toIndentedString(amount)).append("\n");
        sb.append("    currency: ").append(toIndentedString(currency)).append("\n");
        sb.append("    status: ").append(toIndentedString(status)).append("\n");
        sb.append("    creditAdj: ").append(toIndentedString(creditAdj)).append("\n");
        sb.append("    refundAdj: ").append(toIndentedString(refundAdj)).append("\n");
        sb.append("    invoiceId: ").append(toIndentedString(invoiceId)).append("\n");
        sb.append("    invoiceDate: ").append(toIndentedString(invoiceDate)).append("\n");
        sb.append("    targetDate: ").append(toIndentedString(targetDate)).append("\n");
        sb.append("    invoiceNumber: ").append(toIndentedString(invoiceNumber)).append("\n");
        sb.append("    balance: ").append(toIndentedString(balance)).append("\n");
        sb.append("    accountId: ").append(toIndentedString(accountId)).append("\n");
        sb.append("    bundleKeys: ").append(toIndentedString(bundleKeys)).append("\n");
        sb.append("    credits: ").append(toIndentedString(credits)).append("\n");
        sb.append("    items: ").append(toIndentedString(items)).append("\n");
        sb.append("    trackingIds: ").append(toIndentedString(trackingIds)).append("\n");
        sb.append("    isParentInvoice: ").append(toIndentedString(isParentInvoice)).append("\n");
        sb.append("    parentInvoiceId: ").append(toIndentedString(parentInvoiceId)).append("\n");
        sb.append("    parentAccountId: ").append(toIndentedString(parentAccountId)).append("\n");
        sb.append("    auditLogs: ").append(toIndentedString(auditLogs)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(java.lang.Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }
}

