/*
 * Copyright 2010-2014 Ning, Inc.
 * Copyright 2014-2020 Groupon, Inc
 * Copyright 2020-2021 Equinix, Inc
 * Copyright 2014-2021 The Billing Project, LLC
 *
 * The Billing Project licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */


package org.killbill.billing.client.model.gen;

import java.util.Objects;
import java.util.Arrays;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import org.killbill.billing.client.model.gen.Duration;
import org.killbill.billing.payment.api.PaymentResponse;
import org.killbill.billing.util.tag.ControlTagType;

/**
 *           DO NOT EDIT !!!
 *
 * This code has been generated by the Kill Bill swagger generator.
 *  @See https://github.com/killbill/killbill-swagger-coden
 */
import org.killbill.billing.client.model.KillBillObject;

public class OverdueCondition {

    private Duration timeSinceEarliestUnpaidInvoiceEqualsOrExceeds = null;

    private ControlTagType controlTagInclusion = null;

    private ControlTagType controlTagExclusion = null;

    private Integer numberOfUnpaidInvoicesEqualsOrExceeds = null;

    private List<PaymentResponse> responseForLastFailedPayment = null;

    private BigDecimal totalUnpaidInvoiceBalanceEqualsOrExceeds = null;


    public OverdueCondition() {
    }

    public OverdueCondition(final Duration timeSinceEarliestUnpaidInvoiceEqualsOrExceeds,
                     final ControlTagType controlTagInclusion,
                     final ControlTagType controlTagExclusion,
                     final Integer numberOfUnpaidInvoicesEqualsOrExceeds,
                     final List<PaymentResponse> responseForLastFailedPayment,
                     final BigDecimal totalUnpaidInvoiceBalanceEqualsOrExceeds) {
        this.timeSinceEarliestUnpaidInvoiceEqualsOrExceeds = timeSinceEarliestUnpaidInvoiceEqualsOrExceeds;
        this.controlTagInclusion = controlTagInclusion;
        this.controlTagExclusion = controlTagExclusion;
        this.numberOfUnpaidInvoicesEqualsOrExceeds = numberOfUnpaidInvoicesEqualsOrExceeds;
        this.responseForLastFailedPayment = responseForLastFailedPayment;
        this.totalUnpaidInvoiceBalanceEqualsOrExceeds = totalUnpaidInvoiceBalanceEqualsOrExceeds;

    }


    public OverdueCondition setTimeSinceEarliestUnpaidInvoiceEqualsOrExceeds(final Duration timeSinceEarliestUnpaidInvoiceEqualsOrExceeds) {
        this.timeSinceEarliestUnpaidInvoiceEqualsOrExceeds = timeSinceEarliestUnpaidInvoiceEqualsOrExceeds;
        return this;
    }

    public Duration getTimeSinceEarliestUnpaidInvoiceEqualsOrExceeds() {
        return timeSinceEarliestUnpaidInvoiceEqualsOrExceeds;
    }

    public OverdueCondition setControlTagInclusion(final ControlTagType controlTagInclusion) {
        this.controlTagInclusion = controlTagInclusion;
        return this;
    }

    public ControlTagType getControlTagInclusion() {
        return controlTagInclusion;
    }

    public OverdueCondition setControlTagExclusion(final ControlTagType controlTagExclusion) {
        this.controlTagExclusion = controlTagExclusion;
        return this;
    }

    public ControlTagType getControlTagExclusion() {
        return controlTagExclusion;
    }

    public OverdueCondition setNumberOfUnpaidInvoicesEqualsOrExceeds(final Integer numberOfUnpaidInvoicesEqualsOrExceeds) {
        this.numberOfUnpaidInvoicesEqualsOrExceeds = numberOfUnpaidInvoicesEqualsOrExceeds;
        return this;
    }

    public Integer getNumberOfUnpaidInvoicesEqualsOrExceeds() {
        return numberOfUnpaidInvoicesEqualsOrExceeds;
    }

    public OverdueCondition setResponseForLastFailedPayment(final List<PaymentResponse> responseForLastFailedPayment) {
        this.responseForLastFailedPayment = responseForLastFailedPayment;
        return this;
    }

    public OverdueCondition addResponseForLastFailedPaymentItem(final PaymentResponse responseForLastFailedPaymentItem) {
        if (this.responseForLastFailedPayment == null) {
            this.responseForLastFailedPayment = new ArrayList<PaymentResponse>();
        }
        this.responseForLastFailedPayment.add(responseForLastFailedPaymentItem);
        return this;
    }

    public List<PaymentResponse> getResponseForLastFailedPayment() {
        return responseForLastFailedPayment;
    }

    public OverdueCondition setTotalUnpaidInvoiceBalanceEqualsOrExceeds(final BigDecimal totalUnpaidInvoiceBalanceEqualsOrExceeds) {
        this.totalUnpaidInvoiceBalanceEqualsOrExceeds = totalUnpaidInvoiceBalanceEqualsOrExceeds;
        return this;
    }

    public BigDecimal getTotalUnpaidInvoiceBalanceEqualsOrExceeds() {
        return totalUnpaidInvoiceBalanceEqualsOrExceeds;
    }

    @Override
    public boolean equals(java.lang.Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OverdueCondition overdueCondition = (OverdueCondition) o;
        return Objects.equals(this.timeSinceEarliestUnpaidInvoiceEqualsOrExceeds, overdueCondition.timeSinceEarliestUnpaidInvoiceEqualsOrExceeds) &&
            Objects.equals(this.controlTagInclusion, overdueCondition.controlTagInclusion) &&
            Objects.equals(this.controlTagExclusion, overdueCondition.controlTagExclusion) &&
            Objects.equals(this.numberOfUnpaidInvoicesEqualsOrExceeds, overdueCondition.numberOfUnpaidInvoicesEqualsOrExceeds) &&
            Objects.equals(this.responseForLastFailedPayment, overdueCondition.responseForLastFailedPayment) &&
            Objects.equals(this.totalUnpaidInvoiceBalanceEqualsOrExceeds, overdueCondition.totalUnpaidInvoiceBalanceEqualsOrExceeds);
    }

    @Override
    public int hashCode() {
        return Objects.hash(timeSinceEarliestUnpaidInvoiceEqualsOrExceeds,
            controlTagInclusion,
            controlTagExclusion,
            numberOfUnpaidInvoicesEqualsOrExceeds,
            responseForLastFailedPayment,
            totalUnpaidInvoiceBalanceEqualsOrExceeds);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OverdueCondition {\n");
        
        sb.append("    timeSinceEarliestUnpaidInvoiceEqualsOrExceeds: ").append(toIndentedString(timeSinceEarliestUnpaidInvoiceEqualsOrExceeds)).append("\n");
        sb.append("    controlTagInclusion: ").append(toIndentedString(controlTagInclusion)).append("\n");
        sb.append("    controlTagExclusion: ").append(toIndentedString(controlTagExclusion)).append("\n");
        sb.append("    numberOfUnpaidInvoicesEqualsOrExceeds: ").append(toIndentedString(numberOfUnpaidInvoicesEqualsOrExceeds)).append("\n");
        sb.append("    responseForLastFailedPayment: ").append(toIndentedString(responseForLastFailedPayment)).append("\n");
        sb.append("    totalUnpaidInvoiceBalanceEqualsOrExceeds: ").append(toIndentedString(totalUnpaidInvoiceBalanceEqualsOrExceeds)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(java.lang.Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }
}

